#include <SDL.h>
#include <stdbool.h>
#include <stdio.h>

const char* APP_NAME = "SDL2";
const unsigned int SCREEN_WIDTH = 640;
const unsigned int SCREEN_HEIGHT = 480;
const unsigned int SCREEN_FPS = 30;

#define SDL_GetTicks64 SDL_GetTicks

int main() {
	SDL_Window* window = NULL;
	SDL_Surface* screenSurface = NULL;

	if (SDL_Init(SDL_INIT_VIDEO) < 0) {
		printf("SDL could not initialize! SDL_Error: %s\n", SDL_GetError());
		return -1;
	}

	window = SDL_CreateWindow(
		APP_NAME,
		SDL_WINDOWPOS_UNDEFINED,
		SDL_WINDOWPOS_UNDEFINED,
		(int) SCREEN_WIDTH,
		(int) SCREEN_HEIGHT,
		SDL_WINDOW_SHOWN
	);

	if (window == NULL) {
		printf("Window could not be created! SDL_Error: %s\n", SDL_GetError());
		return -2;
	}

	bool quit = false;
	SDL_Event e;
	screenSurface = SDL_GetWindowSurface(window);

	uint64_t start = SDL_GetTicks64();
	unsigned int seconds_elapsed = 0;
	uint64_t last_update = start;
	unsigned int frames = 0;
	while (!quit) {
		while (SDL_PollEvent(&e) != 0) {
			if (e.type == SDL_QUIT) {
				quit = true;
			}
		}

		unsigned int current_ticks = SDL_GetTicks64();
		unsigned int delta = current_ticks - last_update;
		unsigned int new_seconds_elapsed = current_ticks / 1000;

		if (new_seconds_elapsed > seconds_elapsed) {
			printf("%u\n", frames);
			frames = 0;
			seconds_elapsed = new_seconds_elapsed;
		}

		if ((float) delta < 1000.f / (float) (SCREEN_FPS + 1)) {
			continue;
		}

		last_update = current_ticks;
		frames += 1;
		SDL_FillRect(screenSurface, NULL, SDL_MapRGB(screenSurface->format, 0xFF, 0xFF, 0xFF));
		SDL_UpdateWindowSurface(window);
	}

	SDL_DestroyWindow(window);
	SDL_Quit();

	return 0;
}
